.BG
.FN Tree
.TL
Fit a Classification or Regression Tree
.DN
Fit a classification or regression tree, including weighted fits.
.CS
Tree(formula=formula(data), data=sys.parent(), weights, subset,
     na.action=na.pass, control=tree.control(nobs, ...),
     method="recursive.partition", split=c("deviance", "gini"),
     model=NULL, x=F, y=T, wts=T, ...)
.RA
.AG formula
A formula expression. The left-hand-side (response)
should be either a numerical vector when a regression tree will be
fitted or a factor, when a classification tree is produced. The
right-hand-side should be a series of numeric or factor or ordered
variables separated by `+'; there should be no interaction terms.
.AG data
A data frame in which to preferentially interpret
`formula', `weights' and `subset'.
.AG weights
Vector of non-negative observational weights; fractional
weights are allowed.
.AG subset
An expression specifying the subset of cases to be used.
.AG na.action
A function to filter missing data from the model
frame. The default is `na.pass' (to do nothing) as `tree'
handles missing values (by dropping them down the tree as far as possible).
.AG control
A list as returned by `tree.control'.
.AG method
character string giving the method to use. The only other
useful value is `"model.frame"'.
.AG split
Splitting criterion to use.
.AG model
If this argument is itself a model frame, then the
`formula' and `data' arguments are ignored, and
`model' is used to define the model.
.AG x
If `T', the matrix of variables for each case is returned.
.AG y
If `T', the response variable is returned.
.AG wts
If `T', the weights are returned.
.AG ...
Additional arguments that are passed to `tree.control'. Normally used
for `mincut', `minsize' or `mindev'.
.RT
An object of class `"tree"'.
.DT
A tree is grown by binary recursive partitioning using the response in
the specified formula and choosing splits from the terms of the
right-hand-side. Numeric variables and ordered factors are divided into
`X < a' and `X > a'; the levels of an unordered factor are divided into
two non-empty groups. The split which maximizes the reduction in
impurity is chosen, the data set split and the process
repeated. Splitting continues until the terminal nodes are too small or
too few to be split.
.PP 
Factor predictor variables can have up to 32 levels. This limit is
imposed for ease of labelling, but since their use in a classification
tree with three or more levels in a response involves a search over
2^(k-1)-1 groupings for k levels, the practical limit is much less.
.PP
The function differs from `tree' in allowing weights for
classification trees, in allowing the Gini index for splits, and in
the interpretation of `mindev' as a proortion of the root node value
(which is how it is documented but not how it is implemented in `tree').
.SH REFERENCES
Breiman L., Friedman J.H., Olshen R.A. and  Stone,  C.J. (1984).
.ul
Classification  and Regression Trees.  
Wadsworth.
.PP
Ripley, B.D. (1996).
.ul
Pattern Recognition and Neural Networks.
Cambridge University Press, Cambridge.
.SA
`tree', `tree.object', `tree.control', `prune.tree', `predict.tree', 
`snip.tree'
.EX
library(MASS)
cpus.ltr <- Tree(log10(perf) ~ syct+mmin+mmax+cach+chmin+chmax, cpus)
cpus.ltr
summary(cpus.ltr)
plot(cpus.ltr);  text(cpus.ltr)

ir.species <- factor(c(rep("s",50), rep("c", 50),
     rep("v", 50)))
ird <- data.frame(rbind(iris[,,1], iris[,,2], iris[,,3]))
ir.tr <- Tree(ir.species ~., ird)
ir.tr
summary(ir.tr)
.KW tree
.WR
